﻿using System;
using System.Collections;
using System.Collections.Generic;
using System.Linq;
using Newtonsoft.Json;
using OpenQA.Selenium;
using OpenQA.Selenium.Firefox;
using OpenQA.Selenium.Support.UI;
using SeleniumExtras.WaitHelpers;

using DeathByCaptcha;

namespace csharpSeleniumExample
{
    class Program
    {
        static void Main(string[] args)
        {
            string _username = "DBC_USERNAME";
            string _password = "DBC_PASSWORD";
            string _captchaUrl = "https://www.google.com/recaptcha/api2/demo";

            using (var driver = new FirefoxDriver())
            {
                driver.Url = _captchaUrl;

                var element = new WebDriverWait(driver, TimeSpan.FromSeconds(10)).Until(
                    ExpectedConditions.PresenceOfAllElementsLocatedBy(By.Id("recaptcha-demo"))).FirstOrDefault();

                var googleKey = element.GetAttribute("data-sitekey");

                var captcha = new Hashtable()
                {
                    {"type", 4},
                    {"token_params", JsonConvert.SerializeObject(new Dictionary<String, String>()
                    {
                        ["googlekey"] = googleKey,
                        ["pageurl"] = _captchaUrl
                    })}
                };

                // Client client = (Client)new DeathByCaptcha.HttpClient(_username, _password);
                Client client = (Client)new DeathByCaptcha.SocketClient(_username, _password);
                Captcha solution = client.Decode(Client.DefaultTimeout, captcha);

                if (solution == null)
                {
                    Console.WriteLine("No captcha solution (maybe implement retry)...closing");
                    return;
                }

                driver.ExecuteScript($"document.getElementById('g-recaptcha-response').value='{solution.Text}'");


                var button = driver.FindElement(By.Id("recaptcha-demo-submit"));
                button.Click();

                try {
                    var success_element = driver.FindElement(By.ClassName("recaptcha-success"));
                    Console.WriteLine(success_element.Text);
                } catch (System.Exception e) {
                    Console.WriteLine($"Success message not found: {e.Message}" );
                }

            }
            Console.WriteLine("End!");
        }
    }
}
